<?php
declare(strict_types=1);

namespace NL\NlMenubuilder\Domain\Model;


use TYPO3\CMS\Extbase\Persistence\ObjectStorage;

/***
 *
 * This file is part of the "Menu Builder" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 *  (c) 2021
 *
 ***/
/**
 * Menu
 */
class Menu extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity implements MenuInterface
{
    use MenuTrait;

    const DEFAULT_TEMPLATE = 'Index';

    /**
     * Name of the menu
     *
     * @var string
     * @TYPO3\CMS\Extbase\Annotation\Validate("NotEmpty")
     */
    protected $title = '';

    /**
     * template
     *
     * @var string
     * @TYPO3\CMS\Extbase\Annotation\Validate("NotEmpty")
     */
    protected $template = self::DEFAULT_TEMPLATE;

    /**
     * items
     *
     * @var ObjectStorage<MenuItem>
     * @TYPO3\CMS\Extbase\Annotation\ORM\Cascade("remove")
     */
    protected $items = null;

    /**
     * __construct
     */
    public function __construct()
    {
        //Do not remove the next line: It would break the functionality
        $this->initStorageObjects();
    }

    /**
     * Initializes all ObjectStorage properties
     * Do not modify this method!
     * It will be rewritten on each save in the extension builder
     * You may modify the constructor of this class instead
     *
     * @return void
     */
    protected function initStorageObjects()
    {
        $this->items = $this->items ?: new ObjectStorage();
    }

    /**
     * Returns the title
     *
     * @return string $title
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * Sets the title
     *
     * @param string $title
     * @return void
     */
    public function setTitle(string $title): string
    {
        $this->title = $title;
    }

    /**
     * Returns the template
     *
     * @return string $template
     */
    public function getTemplate(): string
    {
        return $this->template;
    }

    /**
     * Sets the template
     *
     * @param string $template
     * @return void
     */
    public function setTemplate(string $template): void
    {
        $this->template = $template;
    }

    /**
     * Adds a MenuItem
     *
     * @param MenuItem $item
     * @return void
     */
    public function addItem(MenuItem $item): void
    {
        $this->items->attach($item);
    }

    /**
     * Removes a MenuItem
     *
     * @param MenuItem $itemToRemove The MenuItem to be removed
     * @return void
     */
    public function removeItem(MenuItem $itemToRemove): void
    {
        $this->items->detach($itemToRemove);
    }

    /**
     * Returns the items
     *
     * @return ObjectStorage<MenuItem> items
     */
    public function getItems(): ?ObjectStorage
    {
        return $this->items;
    }

    /**
     * Sets the items
     *
     * @param ObjectStorage<MenuItem> $items
     * @return void
     */
    public function setItems(ObjectStorage $items): void
    {
        $this->items = $items;
    }
}
