<?php

namespace NL\NlMenubuilder\ViewHelpers\Menu;

use FluidTYPO3\Vhs\Traits\TemplateVariableViewHelperTrait;
use NL\NlMenubuilder\Domain\Model\Menu;
use NL\NlMenubuilder\Domain\Repository\MenuRepository;
use NL\NlMenubuilder\Service\MenuSecurityService;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Object\ObjectManager;
use TYPO3Fluid\Fluid\Core\Rendering\RenderingContextInterface;
use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractViewHelper;
use TYPO3Fluid\Fluid\Core\ViewHelper\Traits\CompileWithRenderStatic;

class GetViewHelper extends AbstractViewHelper
{
    use CompileWithRenderStatic;
    use TemplateVariableViewHelperTrait;

    /**
     * @var boolean
     */
    protected $escapeChildren = false;

    /**
     * @var boolean
     */
    protected $escapeOutput = false;

    /**
     * @return void
     */
    public function initializeArguments(): void
    {
        $this->registerAsArgument();
        $this->registerArgument('uid', 'int', 'UID of the menu', true, 0);
        $this->registerArgument('disableSecurityCheck', 'bool', 'Disable security check', false, false);
    }

    /**
     * @param array $arguments
     * @param \Closure $renderChildrenClosure
     * @param RenderingContextInterface $renderingContext
     * @return mixed|string
     * @throws \TYPO3\CMS\Extbase\Object\Exception
     */
    public static function renderStatic(array $arguments, \Closure $renderChildrenClosure, RenderingContextInterface $renderingContext)
    {
        /** @var ObjectManager $objectManager */
        $objectManager = GeneralUtility::makeInstance(ObjectManager::class);

        /** @var MenuRepository $menuRepository */
        $menuRepository = $objectManager->get(MenuRepository::class);

        /** @var Menu $menu */
        $menu = $menuRepository->findByUid($arguments['uid'] ?? 0);

        if (!$arguments['disableSecurityCheck']) {
            /** @var MenuSecurityService $menuSecurityService */
            $menuSecurityService = $objectManager->get(MenuSecurityService::class);

            $menuSecurityService->applySecurityCheck($menu);
        }

        return static::renderChildrenWithVariableOrReturnInputStatic(
            $menu,
            $arguments['as'],
            $renderingContext,
            $renderChildrenClosure
        );
    }
}
